function msfThreshold(block)
%% Level-2 M-File S-Function for thresholding images
%% RIPAC Blockset
%%=========================================================================
setup(block);
  
function g = Threshold(f,thr)
    g = f;
    f = f(:,:) >= thr;
    g = uint8(f) .* g;
       
%% Function: setup ========================================================
function setup(block)

    % Register number of ports
    block.NumInputPorts  = 1;
    block.NumOutputPorts = 1;
  
    % Setup port properties to be inherited or dynamic
    block.SetPreCompInpPortInfoToDynamic;
    block.SetPreCompOutPortInfoToDynamic;
  
    % Override input port properties
    block.InputPort(1).DatatypeID  = 3; % uint8
    block.InputPort(1).Complexity  = 'Real';
    block.InputPort(1).SamplingMode = 'Sample';
    block.InputPort(1).Overwritable = false; % No in-place operation
  
    % Override output port properties
    block.OutputPort(1).DatatypeID  = 3; % uint8
    block.OutputPort(1).Complexity  = 'Real';
    block.OutputPort(1).SamplingMode = 'Sample';
   
    % Register parameters
    block.NumDialogPrms     = 1;
    block.DialogPrmsTunable = {'Tunable'};
    
    % Register methods
    block.RegBlockMethod('Outputs',@Output);
%% End of Function: setup ================================================= 

%% Function: Output =======================================================
function Output(block)
    thr = block.DialogPrm(1).Data;
    block.OutputPort(1).Data = Threshold(block.InputPort(1).Data,thr);    
%% End of Function: Output ================================================